@@ -34,7 +34,7 @@ class upconfig(object):
         :return:
         """
         try:
-            with open('new_config.ini') as f:
+            with open(self.updatePath, encoding="utf-8-sig") as f:
                 self.config.read_file(f)
             data = self.config.get(self.update_tag, f'{name}')
         except:
@@ -65,7 +65,7 @@ class upconfig(object):
         :return:
         """
         try:
-            with open('new_config.ini') as f:
+            with open(self.updatePath, encoding="utf-8-sig") as f:
                 self.config.read_file(f)
             value = self.config.get(self.update_tag, f'{name}')
         except:
